import logging

class log():
    def __init__(self, module, debug=False):
        self.module = module
        self.logger = logging.getLogger(self.module)
        self.log = logging.StreamHandler()
        self.logformatter = logging.Formatter(fmt='[%(asctime)s][%(name)s][%(levelname)s]: %(message)s', datefmt='%m-%d-%Y %H:%M:%S')

        if debug is True:
            logging.getLogger(self.module).setLevel(logging.DEBUG)
            self.loglevel = 'DEBUG'
        else:
            logging.getLogger(self.module).setLevel(logging.INFO)
            self.loglevel = 'INFO'
        
        self.logger.handlers.clear()
        if not self.logger.hasHandlers():
            self.log.setFormatter(self.logformatter)
            self.logger.addHandler(self.log)

        self.setLevel(self.loglevel)
        

    def setLevel(self, level='DEBUG'):
        try:
            if level.upper() == 'DEBUG':
                logging.getLogger(self.module).setLevel(logging.DEBUG)
                self.loglevel = level.upper()
                self.debug('DEBUG MODE ENABLED.')
            elif level.upper() == 'INFO':
                logging.getLogger(self.module).setLevel(logging.INFO)
                self.loglevel = level.upper()
                self.log('NORMAL MODE ENABLED.')
            elif level.upper() == 'WARNING':
                logging.getLogger(self.module).setLevel(logging.WARNING)
                self.loglevel = level.upper()
            elif level.upper() == 'ERROR':
                logging.getLogger(self.module).setLevel(logging.ERROR)
                self.loglevel = level.upper()
            elif level.upper() == 'CRITICAL':
                logging.getLogger(self.module).setLevel(logging.CRITICAL) 
                self.loglevel = level.upper()
            else:
                return False
            return True
        except:
            return False

    def debug(self, msg):
        try:
            return self.logger.debug(msg)
        except:
            return False

    def info(self, msg):
        try:
            return self.logger.info(msg)
        except:
            return False

    def warning(self, msg):
        try:
            return self.logger.warning(msg)
        except:
            return False

    def error(self, msg):
        try:
            return self.logger.error(msg)
        except:
            return False

    def critical(self, msg):
        try:
            return self.logger.critical(msg)
        except:
            return False


import setuptools
import os

def read():
    tmp = ""
    path = os.path.dirname(os.path.abspath(__file__))
    with open(os.path.join(path, 'README.md'), encoding='utf-8') as f:
        tmp = f.read()
    return tmp

setuptools.setup(
    name="Felog",
    version="1.0.1",
    author="Felix Hernandez",
    description="Felog is yet another simple logging library to quickly and simply deploy logging with projects.",
    packages=["felog"],
    # install_requires=["logging"],
    url="https://github.com/basegodfelix/felog",
    long_description = read(),
    long_description_content_type = 'text/markdown',
    license="MIT"
)